@@ -30,11 +30,17 @@ GWEN_INHERIT_FUNCTION_LIB_DEFS(GWEN_HTTP_SESSION, GWENHYWFAR_API)
 #include <gwenhywfar/buffer.h>
 
 
+#ifndef NO_DEPRECATED_SYMBOLS
 /**
  * This flag forces SSLv3 connections when in HTTPS mode.
  */
-#define GWEN_HTTP_SESSION_FLAGS_FORCE_SSL3 0x00000001
-#define GWEN_HTTP_SESSION_FLAGS_NO_CACHE   0x00000002
+#define GWEN_HTTP_SESSION_FLAGS_FORCE_SSL3               0x00000001	/* deprecated, will be removed in a future release */
+#endif // ifndef NO_DEPRECATED_SYMBOLS
+#define GWEN_HTTP_SESSION_FLAGS_NO_CACHE                 0x00000002
+#ifndef NO_DEPRECATED_SYMBOLS
+#define GWEN_HTTP_SESSION_FLAGS_TLS_ONLY_SAFE_CIPHERS    0x00000004	/* deprecated, will be removed in a future release */
+#define GWEN_HTTP_SESSION_FLAGS_TLS_FORCE_UNSAFE_CIPHERS 0x00000008	/* deprecated, will be removed in a future release */
+#endif // ifndef NO_DEPRECATED_SYMBOLS
 
 
 #ifdef __cplusplus
@@ -141,8 +147,8 @@ int GWEN_HttpSession_Fini(GWEN_HTTP_SESSION *sess);
  */
 GWENHYWFAR_API
 int GWEN_HttpSession_SendPacket(GWEN_HTTP_SESSION *sess,
-				const char *httpCommand,
-				const uint8_t *buf, uint32_t blen);
+                                const char *httpCommand,
+                                const uint8_t *buf, uint32_t blen);
 
 /**
  * This function receives a response packet from the server and closes
